==> sources_fancymenu_forge_3.8.0_MC_1.19.2.jar: de/keksuccino/fancymenu/customization/element/elements/playerentity/model/PlayerEntityProperties.java <==
package de.keksuccino.fancymenu.customization.element.elements.playerentity.model;

import de.keksuccino.fancymenu.util.rendering.text.Components;
import net.minecraft.client.resources.DefaultPlayerSkin;
import net.minecraft.core.Direction;
import net.minecraft.network.chat.Component;
import net.minecraft.resources.ResourceLocation;
import net.minecraft.world.InteractionHand;
import net.minecraft.world.entity.*;
import net.minecraft.world.entity.player.PlayerModelPart;
import net.minecraft.world.item.ItemStack;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

@SuppressWarnings("all")
public class PlayerEntityProperties {

    public double xo;
    public double yo;
    public double zo;

    public float xRot;
    public float xRotO;
    public float yRot;
    public float yBodyRot;
    public float yBodyRotO;
    public float yHeadRot;
    public float yHeadRotO;

    public double xCloak;
    public double xCloakO;
    public double yCloak;
    public double yCloakO;
    public double zCloak;
    public double zCloakO;

    public float headZRot;

    public float leftArmXRot;
    public float leftArmYRot;
    public float leftArmZRot;

    public float rightArmXRot;
    public float rightArmYRot;
    public float rightArmZRot;

    public float leftLegXRot;
    public float leftLegYRot;
    public float leftLegZRot;

    public float rightLegXRot;
    public float rightLegYRot;
    public float rightLegZRot;

    public float bob;
    public float oBob;

    public float animationSpeedOld;
    public float animationSpeed;
    public float animationPosition;
    public int tickCount = 1000;

    protected volatile ResourceLocation playerSkinLocation = DefaultPlayerSkin.getDefaultSkin();
    protected volatile ResourceLocation capeLocation = null;
    public boolean shouldSit = false;
    public boolean isBaby = false;
    public boolean crouching = false;
    public boolean spectator = false;
    public boolean invisible = false;
    /** not functional **/
    public boolean glowing = false;
    public boolean hasParrotOnShoulder = false;
    public int shoulderParrotVariant = 0;
    public boolean parrotOnLeftShoulder = false;
    public boolean showDisplayName = true;
    public Component displayName = Components.literal("Steve");

    private final boolean slim;

    public PlayerEntityProperties(boolean slim) {
        this.slim = slim;
    }

    public boolean isSlim() {
        return this.slim;
    }

    public boolean isModelPartShown(PlayerModelPart part) {
        return true;
    }

    public boolean isSpectator() {
        return this.spectator;
    }

    public boolean isCrouching() {
        return this.crouching;
    }

    public HumanoidArm getMainArm() {
        return HumanoidArm.RIGHT;
    }

    public ItemStack getOffhandItem() {
        return ItemStack.EMPTY;
    }

    public ItemStack getItemInHand(InteractionHand hand) {
        return ItemStack.EMPTY;
    }

    public InteractionHand getUsedItemHand() {
        return InteractionHand.MAIN_HAND;
    }

    public long getUseItemRemainingTicks() {
        return 0L;
    }

    public boolean hasPose(Pose pose) {
        return false;
    }

    public Direction getBedOrientation() {
        return Direction.SOUTH;
    }

    @NotNull
    public ResourceLocation getSkinTextureLocation() {
        if (this.playerSkinLocation == null) {
            return DefaultPlayerSkin.getDefaultSkin();
        }
        return this.playerSkinLocation;
    }

    public void setSkinTextureLocation(ResourceLocation loc) {
        this.playerSkinLocation = loc;
    }

    public float getEyeHeight(Pose pose) {
        return getEyeHeight(pose, this.getDimensions());
    }

    protected float getEyeHeight(Pose pose, EntityDimensions entityDimensions) {
        return pose == Pose.SLEEPING ? 0.2F : (entityDimensions.height * 0.85F);
    }

    @Nullable
    public ResourceLocation getCapeTextureLocation() {
        return this.capeLocation;
    }

    public void setCapeTextureLocation(ResourceLocation loc) {
        this.capeLocation = loc;
    }

    public EntityType getType() {
        return EntityType.PLAYER;
    }

    public EntityDimensions getDimensions() {
        return this.getType().getDimensions();
    }

}

==> sources_fancymenu_forge_3.8.1_MC_1.20.1.jar: de/keksuccino/fancymenu/customization/element/elements/playerentity/model/PlayerEntityProperties.java <==
package de.keksuccino.fancymenu.customization.element.elements.playerentity.model;

import net.minecraft.client.resources.DefaultPlayerSkin;
import net.minecraft.core.Direction;
import net.minecraft.network.chat.Component;
import net.minecraft.resources.ResourceLocation;
import net.minecraft.world.InteractionHand;
import net.minecraft.world.entity.*;
import net.minecraft.world.entity.player.PlayerModelPart;
import net.minecraft.world.item.ItemStack;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

@SuppressWarnings("all")
public class PlayerEntityProperties {

    public double xo;
    public double yo;
    public double zo;

    public float xRot;
    public float xRotO;
    public float yRot;
    public float yBodyRot;
    public float yBodyRotO;
    public float yHeadRot;
    public float yHeadRotO;

    public double xCloak;
    public double xCloakO;
    public double yCloak;
    public double yCloakO;
    public double zCloak;
    public double zCloakO;

    public float headZRot;

    public float leftArmXRot;
    public float leftArmYRot;
    public float leftArmZRot;

    public float rightArmXRot;
    public float rightArmYRot;
    public float rightArmZRot;

    public float leftLegXRot;
    public float leftLegYRot;
    public float leftLegZRot;

    public float rightLegXRot;
    public float rightLegYRot;
    public float rightLegZRot;

    public float bob;
    public float oBob;

    public float animationSpeedOld;
    public float animationSpeed;
    public float animationPosition;
    public int tickCount = 1000;

    protected volatile ResourceLocation playerSkinLocation = DefaultPlayerSkin.getDefaultSkin();
    protected volatile ResourceLocation capeLocation = null;
    public boolean shouldSit = false;
    public boolean isBaby = false;
    public boolean crouching = false;
    public boolean spectator = false;
    public boolean invisible = false;
    /** not functional **/
    public boolean glowing = false;
    public boolean hasParrotOnShoulder = false;
    public int shoulderParrotVariant = 0;
    public boolean parrotOnLeftShoulder = false;
    public boolean showDisplayName = true;
    public Component displayName = Component.literal("Steve");

    private final boolean slim;

    public PlayerEntityProperties(boolean slim) {
        this.slim = slim;
    }

    public boolean isSlim() {
        return this.slim;
    }

    public boolean isModelPartShown(PlayerModelPart part) {
        return true;
    }

    public boolean isSpectator() {
        return this.spectator;
    }

    public boolean isCrouching() {
        return this.crouching;
    }

    public HumanoidArm getMainArm() {
        return HumanoidArm.RIGHT;
    }

    public ItemStack getOffhandItem() {
        return ItemStack.EMPTY;
    }

    public ItemStack getItemInHand(InteractionHand hand) {
        return ItemStack.EMPTY;
    }

    public InteractionHand getUsedItemHand() {
        return InteractionHand.MAIN_HAND;
    }

    public long getUseItemRemainingTicks() {
        return 0L;
    }

    public boolean hasPose(Pose pose) {
        return false;
    }

    public Direction getBedOrientation() {
        return Direction.SOUTH;
    }

    @NotNull
    public ResourceLocation getSkinTextureLocation() {
        if (this.playerSkinLocation == null) {
            return DefaultPlayerSkin.getDefaultSkin();
        }
        return this.playerSkinLocation;
    }

    public void setSkinTextureLocation(ResourceLocation loc) {
        this.playerSkinLocation = loc;
    }

    public float getEyeHeight(Pose pose) {
        return getEyeHeight(pose, this.getDimensions());
    }

    protected float getEyeHeight(Pose pose, EntityDimensions entityDimensions) {
        return pose == Pose.SLEEPING ? 0.2F : (entityDimensions.height * 0.85F);
    }

    @Nullable
    public ResourceLocation getCapeTextureLocation() {
        return this.capeLocation;
    }

    public void setCapeTextureLocation(ResourceLocation loc) {
        this.capeLocation = loc;
    }

    public EntityType getType() {
        return EntityType.PLAYER;
    }

    public EntityDimensions getDimensions() {
        return this.getType().getDimensions();
    }

}
